<?php
namespace Ep\Woo\Form\View\Element;

use Ep\Woo\Product\ProductInterface;
use Ep\Woo\View\AbstractView;

/**
 * Class Quantity
 *
 * @package Ep\Woo\Form\View\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Quantity extends AbstractView
{
    /** @var array */
    protected $templateOverrides = [
        'global/quantity-input.php',
    ];

    /**
     * Inicijalizacija.
     */
    public function init(): void
    {
        parent::init();

        add_filter('woocommerce_cart_item_quantity', [$this, 'renderInCart'], 10, 3);
    }

    /**
     * Renderira view.
     *
     * @return string
     */
    public function render(): string
    {
        $args = func_get_args()[3];

        return $this->renderDiv([
            'value' => $args['input_value'] ?? null,
            'min' => $args['min_value'] ?? null,
            'max' => $args['max_value'] ?? null,
            'step' => $args['step'] ?? null,
            'name' => $args['input_name'] ?? null,
        ]);
    }

    /**
     * @param $product_quantity
     * @param $cart_item_key
     * @param $cart_item
     *
     * @return mixed
     */
    public function renderInCart(/** @noinspection PhpUnusedParameterInspection */ $product_quantity, $cart_item_key, $cart_item)
    {
        /** @var ProductInterface $product */
        $product = wc_get_product($cart_item['product_id']);

        return $this->renderDiv([
            'value' => $cart_item['quantity'],
            'min' => 0,
            'max' => $product->getMaxPurchaseQuantity(),
            'step' => $product->getPurchaseStep(),
            'name' => sprintf('cart[%s][qty]', $cart_item_key),
        ]);
    }

    private function renderDiv(array $attributes): string
    {
        $attributes['type'] = 'quantity-input';
        $renderedAttributes = [];

        foreach (array_filter($attributes) as $name => $value) {
            $renderedAttributes[] = sprintf('data-%s="%s"', $name, $value);
        }

        /** @noinspection HtmlUnknownAttribute */
        return sprintf('<div %s></div>', implode(' ', $renderedAttributes));
    }
}